/**
  *  \file modify.c
  *  \brief Modify PCONFIG.SRC
  *
  *  (c) copyright 2001 Stefan Reuther, Thomas Klebes.
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  version 2, as published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */

#include <string.h>
#include "mfq.h"

static char the_text[1024];     /**< New value for the MaximumMinefieldsPerPlayer option */
static FILE* the_tmpfile;       /**< Temp file we're writing the new pconfig to. */
static Boolean found_it;        /**< True iff we have already modified the option. */

/** Copy file, modifying the MaximumMinefieldsPerPlayer option.
    Used with ConfigFileReader. */
static Boolean
copyAssignFunc(const char* lhs, char* rhs, const char* line)
{
    UNUSED(rhs);
    if (!lhs || !StrEq(lhs, OPTION_NAME)) {
        fputs(line, the_tmpfile);
    } else {
        /* this is the line we're going to modify. */
        const char* p = strchr(line, '=');
        if (p) {
            fprintf(the_tmpfile, "%.*s= %s\n", p - line, line, the_text);
        } else {
            /* can this happen? */
            fprintf(the_tmpfile, "%s = %s\n", OPTION_NAME, the_text);
        }
        found_it = True;
    }
    return True;
}

/** Modify pconfig.src. Sets the MaximumMinefieldsPerPlayer option
    to the values specified in \c data. */
void
modifyPConfig(Uns16 data[])
{
    int i;
    int all_the_same;
    FILE* fp;

    /* use short form? */
    all_the_same = 1;
    for (i = 2; i <= 11; ++i)
        if (data[i] != data[1])
            all_the_same = 0;

    /* generate new value */
    if (all_the_same) {
        sprintf(the_text, "%ld", (long) data[1]);
    } else {
        sprintf(the_text, "%ld, %ld, %ld, %ld, %ld, %ld, %ld, %ld, %ld, %ld, %ld",
                (long) data[1], (long) data[2], (long) data[3],
                (long) data[4], (long) data[5], (long) data[6],
                (long) data[7], (long) data[8], (long) data[9],
                (long) data[10], (long) data[11]);
    }

    /* write new pconfig.src */
    found_it = False;
    fp = OpenInputFile("pconfig.src", TEXT_MODE | GAME_DIR_ONLY);
    the_tmpfile = OpenOutputFile("pconfig.mfq", TEXT_MODE | GAME_DIR_ONLY);
    ConfigFileReader(fp, "pconfig.src", "phost", True, copyAssignFunc);

    if (!found_it) {
        fprintf(the_tmpfile, "%% PHOST\n%s = %s\n", OPTION_NAME, the_text);
        Warning("The current `pconfig.src' did not contain a");
        Warning("`%s' option. I added one at the end.", OPTION_NAME);
    }
    fclose(fp);
    fclose(the_tmpfile);

    if (flag_readonly) {
        Info("Read-only operation: leaving new `pconfig.src' file as `pconfig.mfq'");
    } else {
        if (!RemoveGameFile("pconfig.src")
            || !RenameGameFile("pconfig.mfq", "pconfig.src")) {
            Error("Unable to modify `pconfig.src'. My modifications are in `pconfig.mfq'.");
        }
    }
}
