/**
  *  \file tmpfile.c
  *  \brief Status save/restore
  *
  *  This contains routines for saving the status to a file and
  *  restoring it again (for the UnmodifyMinefieldQuotas option).
  *  Since this file only exists during the host run, we don't
  *  bother making it portable.
  *
  *  (c) copyright 2001 Stefan Reuther, Thomas Klebes.
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  version 2, as published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */

#include "mfq.h"

#define TEMPFILE "mfq.hst"

/** Save the current value of the `MaximumMinefieldsPerPlayer'
    option to our temp file. */
void
saveStatus(Uns16 data[])
{
    FILE* fp;

    Info("Saving old minefield quotas...");
    fp = OpenOutputFile(TEMPFILE, GAME_DIR_ONLY);
    fwrite(&data[1], sizeof(data[1]), 11, fp);
    fclose(fp);
}

/** Load temp file into data. */
void
loadStatus(Uns16 data[])
{
    FILE* fp;

    Info("Loading old minefield quotas...");
    fp = OpenInputFile(TEMPFILE, GAME_DIR_ONLY);
    if (fread(&data[1], sizeof(data[1]), 11, fp) != 11)
        ErrorExit("Error reading `%s'.", TEMPFILE);
    fclose(fp);
    RemoveGameFile(TEMPFILE);
}
